﻿using System;

namespace ES.Infrastructure35.ComponentModel_.DataAnnotations_
{
    [AttributeUsage(AttributeTargets.Property, AllowMultiple = false, Inherited = false)]
    public class CustomRangeAttribute : CustomValidationBaseAttribute
    {
        private object m_Minimum = null;
        public object Minimum { get { return m_Minimum; } }

        private object m_Maximum = null;
        public object Maximum { get { return m_Maximum; } }

        private Type m_OperandType = null;
        public Type OperandType { get { return m_OperandType; } }

        public CustomRangeAttribute(Int32 minimum, Int32 maximum) : this(minimum, maximum, typeof(Int32)) { }

        public CustomRangeAttribute(double minimum, double maximum) : this(minimum, maximum, typeof(Double)) { }

        public CustomRangeAttribute(string minimum, string maximum) : this(minimum, maximum, typeof(string)) { }

        private CustomRangeAttribute(object minimum, object maximum, Type operandType)
        {
            m_Minimum = minimum;
            m_Maximum = maximum;
            m_OperandType = operandType;
        }

        public override string FormatErrorMessage(string displayName)
        {
            return string.Format(ErrorMessage, displayName, Minimum, Maximum);
        }

        protected override bool IsValid(object valueObj)
        {
            if (valueObj == null || valueObj.GetType() != m_OperandType)
                return false;

            var minimum = (IComparable)Minimum;
            if (minimum == null)
                return false;

            var value = (IComparable)valueObj;
            if (minimum.CompareTo(value) > -1)
                return false;

            if (value.CompareTo((IComparable)Maximum) > -1)
                return false;

            return true;
        }
    }
}
