﻿using System;

namespace ES.Infrastructure35.ComponentModel_.DataAnnotations_
{
    [AttributeUsage(AttributeTargets.Property, AllowMultiple = false, Inherited = false)]
    public class CustomStringLengthAttribute : CustomValidationBaseAttribute
    {
        private Int32 m_MinimumLength = 0;
        public Int32 MinimumLength { get { return m_MinimumLength; } }

        private Int32 m_MaximumLength = 0;
        public Int32 MaximumLength
        {
            get { return m_MaximumLength; }
            set { m_MaximumLength = value; }
        }

        public CustomStringLengthAttribute(Int32 maximumLength) : this(maximumLength, 0) { }

        public CustomStringLengthAttribute(Int32 maximumLength, Int32 minimumLength)
        {
            m_MaximumLength = maximumLength;
            m_MinimumLength = minimumLength;
        }

        public override string FormatErrorMessage(string displayName)
        {
            return string.Format(ErrorMessage, displayName, MaximumLength, MinimumLength);
        }

        protected override bool IsValid(object value)
        {
            var valueLength = value == null ? 0 : value.ToString().Length;
            return valueLength >= MinimumLength && valueLength <= MaximumLength;
        }
    }
}
