﻿using System;
using System.Linq.Expressions;
using System.Web.Mvc;
using ES.WebInfrastructure35.EasyUI;
using ES.WebInfrastructure35.EasyUI.Builder;

namespace ES.Mvc40.EasyUI
{
    public static class EasyUIExtensionMethod
    {
        public static MvcHtmlString ValidateText<TModel>(
            this HtmlHelper<TModel> htmlHelper,
            Expression<Func<TModel, object>> expression,
            string attributeJson = null)
        {
            return MvcHtmlString.Create(EasyUIHelper.ValidateText(expression, htmlHelper.ViewData.Model, attributeJson));
        }

        public static MvcHtmlString ValidatePassword<TModel>(
            this HtmlHelper<TModel> htmlHelper,
            Expression<Func<TModel, object>> expression,
            string attributeJson = null)
        {
            return MvcHtmlString.Create(EasyUIHelper.ValidatePassword(expression, htmlHelper.ViewData.Model, attributeJson));
        }

        public static MvcHtmlString Linkbutton<TModel>(this HtmlHelper<TModel> htmlHelper, string text, string attributeJson = null)
        {
            return MvcHtmlString.Create(EasyUIHelper.Linkbutton(text, attributeJson));
        }

        public static MvcHtmlString Combobox<TModel>(
            this HtmlHelper<TModel> htmlHelper,
            Expression<Func<TModel, object>> expression,
            string sourceProeprtyName,
            string attributeJson = null)
        {
            return MvcHtmlString.Create(
                EasyUIHelper.Combobox<TModel>(expression, htmlHelper.ViewData.Model, sourceProeprtyName, attributeJson));
        }

        public static MvcHtmlString Numberbox<TModel>(
            this HtmlHelper<TModel> htmlHelper,
            Expression<Func<TModel, object>> expression,
            string attributeJson = null)
        {
            return MvcHtmlString.Create(EasyUIHelper.Numberbox(expression, htmlHelper.ViewData.Model, attributeJson));
        }

        public static MvcHtmlString Datebox<TModel>(
            this HtmlHelper<TModel> htmlHelper,
            Expression<Func<TModel, object>> expression,
            string attributeJson = null)
        {
            return MvcHtmlString.Create(EasyUIHelper.Datebox(expression, htmlHelper.ViewData.Model, attributeJson));
        }

        public static EasyUIForm BeginEasyUIForm(this HtmlHelper htmlHelper, string id = null, string method = "post")
        {
            var formBuilder = new FormBuilder();
            htmlHelper.ViewContext.Writer.Write(
                formBuilder.CreateBeginHtml(htmlHelper.ViewContext.HttpContext.Request.RawUrl, id, method));
            return new EasyUIForm(htmlHelper.ViewContext, formBuilder);
        }
    }
}