﻿using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Reflection;
using System.Web.Mvc;
using ES.Infrastructure35.Reflection_;
using ES.WebInfrastructure35.EasyUI.Builder;
using ES.WebInfrastructure35.Web_;

namespace ES.Mvc40.EasyUI
{
    public class MvcValidationAttributeBuilder : IValidationAttributeBuilder
    {
        public void AppendTagBuilderAttribute(TagBuilder tag, PropertyInfo property)
        {
            ValidationAttribute[] validationAttrs;
            if (!property.TryGetAttributes(out validationAttrs))
                return;

            var attribute = validationAttrs.FirstOrDefault(attr => attr is RequiredAttribute);
            if (attribute != null)
            {
                tag.AddAttribute("required", "true");
                tag.AddAttribute("missingMessage", attribute.ErrorMessage);
            }

            attribute = validationAttrs.FirstOrDefault(attr => !(attr is RequiredAttribute));
            if (attribute == null)
                return;

            if (attribute is StringLengthAttribute)
            {
                var stringLengthAttr = attribute as StringLengthAttribute;
                tag.AddAttribute("invalidMessage", stringLengthAttr.ErrorMessage);
                tag.AddAttribute("validType", "length[{0}, {1}]", stringLengthAttr.MinimumLength, stringLengthAttr.MaximumLength);
            }
            else if (attribute is RegularExpressionAttribute)
            {
                var regularAttr = attribute as RegularExpressionAttribute;
                tag.AddAttribute(
                    "validType",
                    "regular['{0}', '{1}']",
                    regularAttr.Pattern.Replace("\\", "\\\\"),
                    regularAttr.ErrorMessage);
            }
            else if (attribute is RangeAttribute)
            {
                var rangeAttr = attribute as RangeAttribute;
                tag.AddAttribute("validType", "range[{0}, {1}, '{2}']", rangeAttr.Minimum, rangeAttr.Maximum, rangeAttr.ErrorMessage);
            }
            else if (attribute is CompareAttribute)
            {
                var compareAttr = attribute as CompareAttribute;
                tag.AddAttribute("validType", "eq['[name={0}]', '{1}']", compareAttr.OtherProperty, compareAttr.ErrorMessage);
            }
        }
    }
}
