﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Web.UI.WebControls;
using ES.Infrastructure35.Reflection_;
using ES.WebInfrastructure35.Web_;

namespace ES.WebInfrastructure35.EasyUI.Builder
{
    internal class ComboboxBuilder<TModel> : ParseExpressionBuilder<TModel>
    {
        private IEnumerable<ListItem> m_items = null;

        public ComboboxBuilder(
            Expression<Func<TModel, object>> expression,
            TModel model,
            string sourcePropertyName,
            string attributeJson)
            : base("select", "combobox", expression, model, attributeJson)
        {
            if (string.IsNullOrEmpty(sourcePropertyName) || model == null)
                return;

            var property = typeof(TModel).GetProperty(sourcePropertyName);
            if (property == null)
                return;

            m_items = property.FastGetValue(model) as IEnumerable<ListItem>;
        }

        protected override void AppendValue(ref TagBuilder builder, object propertyValue)
        {
            if (m_items == null)
                return;

            string value = (propertyValue ?? string.Empty).ToString();
            builder.Content = string.Join("", m_items.Select(item =>
            {
                TagBuilder optionBuilder = new TagBuilder("option", new Dictionary<string, string>
                {
                    { "value", item.Value }
                });

                if (value == item.Value)
                    optionBuilder.AddAttribute("selected", "true");

                optionBuilder.Content = item.Text;
                return optionBuilder.ToString();
            }).ToArray());
        }
    }
}
