﻿using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using ES.Infrastructure35;
using ES.Infrastructure35.ComponentModel_.DataAnnotations_;
using ES.WebInfrastructure35.Web_;

namespace ES.WebInfrastructure35.EasyUI.Builder
{
    public class CustomValidationAttributeBuilder : IValidationAttributeBuilder
    {
        public void AppendTagBuilderAttribute(TagBuilder tag, PropertyInfo property)
        {
            IEnumerable<CustomValidationBaseAttribute> validationAttrs = ObjectHelper.GetCustomValidations(property);
            if (!validationAttrs.Any())
                return;

            var attribute = validationAttrs.FirstOrDefault(attr => attr is CustomRequiredAttribute);
            if (attribute != null)
            {
                tag.AddAttribute("required", "true");
                tag.AddAttribute("missingMessage", attribute.ErrorMessage);
            }

            attribute = validationAttrs.FirstOrDefault(attr => !(attr is CustomRequiredAttribute));
            if (attribute == null)
                return;

            if (attribute is CustomStringLengthAttribute)
            {
                var stringLengthAttr = attribute as CustomStringLengthAttribute;
                tag.AddAttribute("invalidMessage", stringLengthAttr.ErrorMessage);
                tag.AddAttribute("validType", "length[{0}, {1}]", stringLengthAttr.MinimumLength, stringLengthAttr.MaximumLength);
            }
            else if (attribute is CustomRegularAttribute)
            {
                var regularAttr = attribute as CustomRegularAttribute;
                tag.AddAttribute(
                    "validType",
                    "regular['{0}', '{1}']",
                    regularAttr.Pattern.Replace("\\", "\\\\"),
                    regularAttr.ErrorMessage);
            }
            else if (attribute is CustomRangeAttribute)
            {
                var rangeAttr = attribute as CustomRangeAttribute;
                tag.AddAttribute("validType", "range[{0}, {1}, '{2}']", rangeAttr.Minimum, rangeAttr.Maximum, rangeAttr.ErrorMessage);
            }
            else if (attribute is CustomCompareAttribute)
            {
                var compareAttr = attribute as CustomCompareAttribute;
                tag.AddAttribute("validType", "eq['[name={0}]', '{1}']", compareAttr.ComparePropertyName, compareAttr.ErrorMessage);
            }
        }
    }
}
