﻿using System;
using System.Linq.Expressions;
using System.Reflection;
using ES.Infrastructure35.Reflection_;
using ES.WebInfrastructure35.Web_;

namespace ES.WebInfrastructure35.EasyUI.Builder
{
    internal class ParseExpressionBuilder<TModel> : BuilderBase
    {
        private object m_Value = null;

        private string m_PropertyName = null;
        public string PropertyName { get { return m_PropertyName; } }

        private PropertyInfo m_Property = null;
        public PropertyInfo Property { get { return m_Property; } }

        public ParseExpressionBuilder(string tag, Expression<Func<TModel, object>> expression, string attributeJson)
            : this(tag, null, expression, default(TModel), attributeJson) { }

        public ParseExpressionBuilder(
            string tag,
            string control,
            Expression<Func<TModel, object>> expression,
            TModel model,
            string attributeJson)
            : base(tag, control, attributeJson)
        {
            m_PropertyName = PropertyHelper.ResloveName(expression);
            Type modelType = typeof(TModel);
            m_Property = modelType.GetProperty(m_PropertyName);
            if (m_Property == null)
                throw new NullReferenceException(string.Format("[{0}]不存在,请检查表达式!", m_PropertyName));

            if (model != null)
                m_Value = expression.Compile()(model);
        }

        protected override void ExpandFor(TagBuilder builder)
        {
            builder.AddAttribute("name", m_PropertyName);
            ValidationAttributeBuilderFactory.Builder.AppendTagBuilderAttribute(builder, Property);
            AppendValue(ref builder, m_Value);
        }

        protected virtual void AppendValue(ref TagBuilder builder, object value)
        {
            if (value != null)
                builder.AddAttribute("value", value.ToString());
        }
    }
}
