﻿using System;
using System.Linq.Expressions;
using ES.WebInfrastructure35.EasyUI.Builder;

namespace ES.WebInfrastructure35.EasyUI
{
    public class EasyUIHelper
    {
        public static string Label<TModel>(Expression<Func<TModel, object>> expression)
        {
            return Label(expression, null);
        }

        public static string Label<TModel>(Expression<Func<TModel, object>> expression, string attributeJson)
        {
            return new LabelBuilder<TModel>(expression, attributeJson);
        }

        public static string ValidateText<TModel>(Expression<Func<TModel, object>> expression)
        {
            return ValidateText(expression, null);
        }

        public static string ValidateText<TModel>(Expression<Func<TModel, object>> expression, TModel model)
        {
            return ValidateText(expression, model, null);
        }

        public static string ValidateText<TModel>(Expression<Func<TModel, object>> expression, string attributeJson)
        {
            return ValidateText(expression, default(TModel), attributeJson);
        }

        public static string ValidateText<TModel>(Expression<Func<TModel, object>> expression, TModel model, string attributeJson)
        {
            return new ValidateboxBuilder<TModel>(expression, model, "text", attributeJson);
        }

        public static string ValidatePassword<TModel>(Expression<Func<TModel, object>> expression)
        {
            return ValidatePassword(expression, null);
        }

        public static string ValidatePassword<TModel>(
            Expression<Func<TModel, object>> expression,
            string attributeJson)
        {
            return ValidatePassword(expression, default(TModel), attributeJson);
        }

        public static string ValidatePassword<TModel>(Expression<Func<TModel, object>> expression, TModel model)
        {
            return ValidatePassword(expression, model, null);
        }

        public static string ValidatePassword<TModel>(Expression<Func<TModel, object>> expression, TModel model, string attributeJson)
        {
            return new ValidateboxBuilder<TModel>(expression, model, "password", attributeJson);
        }

        public static string Linkbutton(string text)
        {
            return new LinkbuttonBuilder(text, null);
        }

        public static string Linkbutton(string text, string attributeJson)
        {
            return new LinkbuttonBuilder(text, attributeJson);
        }

        public static string Combobox<TModel>(Expression<Func<TModel, object>> expression, TModel model, string sourceProeprtyName)
        {
            return Combobox(expression, model, sourceProeprtyName, null);
        }

        public static string Combobox<TModel>(
            Expression<Func<TModel, object>> expression,
            TModel model,
            string sourceProeprtyName,
            string attributeJson)
        {
            return new ComboboxBuilder<TModel>(expression, model, sourceProeprtyName, attributeJson);
        }

        public static string Numberbox<TModel>(Expression<Func<TModel, object>> expression)
        {
            return Numberbox(expression, null);
        }

        public static string Numberbox<TModel>(Expression<Func<TModel, object>> expression, string attributeJson)
        {
            return Numberbox(expression, default(TModel), attributeJson);
        }

        public static string Numberbox<TModel>(Expression<Func<TModel, object>> expression, TModel model)
        {
            return Numberbox(expression, model, null);
        }

        public static string Numberbox<TModel>(Expression<Func<TModel, object>> expression, TModel model, string attributeJson)
        {
            return new NumberboxBuilder<TModel>(expression, model, attributeJson);
        }

        public static string Datebox<TModel>(Expression<Func<TModel, object>> expression)
        {
            return Datebox(expression, null);
        }

        public static string Datebox<TModel>(Expression<Func<TModel, object>> expression, string attributeJson)
        {
            return Datebox(expression, default(TModel), attributeJson);
        }

        public static string Datebox<TModel>(Expression<Func<TModel, object>> expression, TModel model)
        {
            return Datebox(expression, model, null);
        }

        public static string Datebox<TModel>(Expression<Func<TModel, object>> expression, TModel model, string attributeJson)
        {
            return new DateboxBuilder<TModel>(expression, model, attributeJson);
        }
    }
}
